
# Lolzteam Python API

<p align="center">
    <a href="https://zelenka.guru/threads/5523020/"><img width="800" src="https://zelenka.guru/styles/brand/download/logos/LolzTeam-Wordmark-Green.svg" alt="Material Bread logo"></a>
</p>

[![Static Badge](https://img.shields.io/badge/DONATE-LOLZTEAM-darkgreen?style=flat-square&logo=qiwi)](https://lzt.market/balance/transfer?user_id=2410024&comment=Thanks%20for%20creating%20LolzteamApi&amount=250)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/AS7RIDENIED/Lolzteam_Python_Api/blob/main/LICENSE)


## Installation

You can install the library using pip:

```cmd
pip install LolzteamApi
```

## Usage

Import the `LolzteamApi` module and create an instance of the `LolzteamApi` class to start using the API:

```python
from LolzteamApi import LolzteamApi
api = LolzteamApi(token='your_token')
```

## Examples

<p align="left">
    <a href="https://github.com/AS7RIDENIED/Lolzteam_Python_Api/blob/main/Examples/example.py"><img width="150" src="https://zelenka.guru/styles/brand/download/logos/LolzTeam-Wordmark-Green.svg" alt="Material Bread logo"></a>
</p>

<p align="left">
    <a href="https://github.com/AS7RIDENIED/Lolzteam_Python_Api/blob/main/Examples/example_market.py"><img width="150" src="https://lzt.market/styles/market/logo_by_DaWeed_X_KASTE.svg" alt="Material Bread logo"></a>
</p>


## Official Lolzteam documentation

<p align="left">
    <a href="https://docs.api.zelenka.guru/?forum"><img width="150" src="https://zelenka.guru/styles/brand/download/logos/LolzTeam-Wordmark-Green.svg" alt="Material Bread logo"></a>
</p>

<p align="left">
    <a href="https://docs.api.zelenka.guru/?market"><img width="150" src="https://lzt.market/styles/market/logo_by_DaWeed_X_KASTE.svg" alt="Material Bread logo"></a>
</p>

